pro random_maps
  !quiet=1
  ;; define the simulated alm's directory and read the file
  ;; paths in an array
  sim_alms_path='/path/to/the/simulated/alms/LILC_sim_recon/ILC_alms/'
  sim_alms=file_search(sim_alms_path+'*')
  nsims=size(sim_alms,/n_elements)
  
  ;; define a temporary file where to store the map obtained from the
  ;; simulated alm
  temp_map='/path/to/a/file/for/the/temporary/map/temp_map.fits'
  
  ;; define the arrays where to store the value of the maximum
  ;; temperature differences and the corresponding pixels
  max_diffs=fltarr(nsims)
  max_diff_pos=uintarr(nsims)
  
  Nside=4
  ;; generate the pixel-antipixel correspondence in the ring scheme
  ;; (since the generated maps are in this scheme)
  pix2vec_ring, Nside, lindgen(nside2npix(Nside)), vectors
  anti_vectors=-vectors
  vec2pix_ring, Nside, anti_vectors, anti_pixels

  for i=0L,nsims-1 do begin
     ;; generate the map from the alm 
     isynfast, '', alm_in=sim_alms[i], temp_map, nside=Nside, $
               tmpdir='/path/to/a/directory/where/to/store/temporary/results/', $
               /silent
     ;; read the map
     read_fits_s, temp_map, map, map_struct
     ;; generate the map of the temperature differences for opposite
     ;; pixels
     differences=map_struct.temperature-map_struct.temperature(anti_pixels)
     ;; store the maximum temperature difference and the position of
     ;; the corresponding pixel
     max_diffs[i]=max(differences,k)
     max_diff_pos[i]=k
  endfor
  
  ;; convert the position of the pixels where the maximum temperature
  ;; difference occurs to angular coordinates
  pix2ang_ring, Nside, max_diff_pos, theta, phi
  theta=theta/!PI*180
  phi=phi/!PI*180
  
  ;; store the results in a txt file in 3 columns
  openw, 1, '/path/to/the/file/where/the/results/will/be/stored/sims_res_nside'+string(Nside)+'.txt'
  for i=0L,nsims-1 do printf, 1, max_diffs[i], theta[i], phi[i] 
  close, 1

end
